biom.table.Table._get_col — biom-format.org

# biom-format.org

## biom.table.Table._get_col

`Table.` `_get_col`(col_idx)

  Return the column at `col_idx`.

  A column vector will be returned as a scipy.sparse matrix in csc format.

  Notes

  Switching between slicing rows and columns is inefficient. Slicing of rows requires a CSR representation, while slicing of columns requires a CSC representation, and transforms are performed on the data if the data are not in the required representation. These transforms can be expensive if done frequently.